==> cryptol-2.6.0-91-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.6.0
id: cryptol-2.6.0-5J8perRm0Ek5RrGowc2kqS
key: cryptol-2.6.0-5J8perRm0Ek5RrGowc2kqS
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: f968d2ad7d82d43f5703d2c57712e315
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Fixity Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Unlit Cryptol.Parser.Utils Cryptol.Prims.Eval
    Cryptol.Prims.Syntax Cryptol.REPL.Command Cryptol.REPL.Monad
    Cryptol.REPL.Trie Cryptol.Symbolic Cryptol.Symbolic.Prims
    Cryptol.Symbolic.Value Cryptol.Testing.Concrete
    Cryptol.Testing.Random Cryptol.Transform.AddModParams
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST
    Cryptol.TypeCheck.CheckModuleInstance Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Depends Cryptol.TypeCheck.Error
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.6.4/site-local/cryptol-2.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/cryptol-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.6.0-5J8perRm0Ek5RrGowc2kqS
depends:
    GraphSCC-1.0.4-3OePO7VIpTKFKEtcZOuY34 array-0.5.3.0 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    monad-control-1.0.2.3-CbJ0M7iQh3tCaJfGqTvvKL
    monadLib-3.9-Ck8eU2kCDDMFvpmDhfp0fP mtl-2.2.2
    panic-0.4.0.1-3YemWx9t6GnDhAma4XQB45 pretty-1.1.3.6 process-1.6.5.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q sbv-7.13-DjO0YuAGvAe3KZ5umxG9Eu
    simple-smt-0.9.4-CTrgrkdTf8HHrgftJ4VNlF
    strict-0.3.2-2aeC0uPBzhhHpNCyMYHGTD text-1.2.3.1
    tf-random-0.5-IjFVdJXpGgq3hBuRJiaT27 time-1.8.0.2
    transformers-base-0.4.5.2-AYmaSZMrRmtI5aj5cOhHJQ
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cryptol-2.6.0-92-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.6.0
id: cryptol-2.6.0-3PNpYxnKXah7abmaStlcXR
key: cryptol-2.6.0-3PNpYxnKXah7abmaStlcXR
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: 24cce250c40dc2e243173ec04ed989a4
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Fixity Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Unlit Cryptol.Parser.Utils Cryptol.Prims.Eval
    Cryptol.Prims.Syntax Cryptol.REPL.Command Cryptol.REPL.Monad
    Cryptol.REPL.Trie Cryptol.Symbolic Cryptol.Symbolic.Prims
    Cryptol.Symbolic.Value Cryptol.Testing.Concrete
    Cryptol.Testing.Random Cryptol.Transform.AddModParams
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST
    Cryptol.TypeCheck.CheckModuleInstance Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Depends Cryptol.TypeCheck.Error
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.6.4/site-local/cryptol-2.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/cryptol-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.6.0-3PNpYxnKXah7abmaStlcXR
depends:
    GraphSCC-1.0.4-3OePO7VIpTKFKEtcZOuY34 array-0.5.3.0 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    monad-control-1.0.2.3-1X2URhF8HacCf5Ysp3ecBG
    monadLib-3.9-Ck8eU2kCDDMFvpmDhfp0fP mtl-2.2.2
    panic-0.4.0.1-3YemWx9t6GnDhAma4XQB45 pretty-1.1.3.6 process-1.6.5.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q sbv-7.13-HnwN8o49H8kCDzZCgtoic2
    simple-smt-0.9.4-CTrgrkdTf8HHrgftJ4VNlF
    strict-0.3.2-2aeC0uPBzhhHpNCyMYHGTD text-1.2.3.1
    tf-random-0.5-IjFVdJXpGgq3hBuRJiaT27 time-1.8.0.2
    transformers-base-0.4.5.2-F1E9AxVLoHK4gnfKIcTrBt
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
